# boltz.exchange python client
A boltz.exchange client for python

## installing
```console
poetry install
```

## running cli
```console
poetry run boltz
```

## starting regtest
```console
cd docker
chmod +x regtest
./regtest
```

## running tests
```console
poetry run pytest
```
